import { useEffect, useState } from 'react'
import { Service } from '../../../Utils/HTTP.js'
import { useSelector } from 'react-redux'
import {
  FormControl, RadioGroup, FormControlLabel, FormLabel, Checkbox,
  TextField, Box, FormGroup, Button, Stack, Collapse
} from '@mui/material'

import { useForm } from "react-hook-form";

import { Simple as Loading } from '../../Generics/loading.jsx'

const ROLE = {
  ADMIN: 1,
  ASISTENTE: 2,
  CANDIDATO: 3,
}

function Marked({ step }) {
  return (<strong className="important_marked">{step}</strong>)
}

function Title({ title, step }) {
  return (<p className="titleMarked">{title}</p>)
}

function PasswordInfoForm({ setUser, user }) {

  return (
    <Stack >
      <Stack direction={{ xs: 'column', sm: 'row' }} spacing={2} >

        <TextField
          value={user?.email}
          onChange={(event) => {
            let value = event.target.value
            setUser({ ...user, ...{ email: value } })
          }
          }
          fullWidth
          id="outlined-basic"
          label="Correo"
          variant="outlined"
        />

        <TextField
          value={user?.password}
          onChange={(event) => {
            let value = event.target.value
            setUser({ ...user, ...{ password: value } })
          }
          }
          fullWidth
          id="outlined-basic"
          label="Contraseña"
          variant="outlined"
        />

      </Stack>
    </Stack>
  );
}



function PermisosList(props) {

  let { recursos,selectedRole, setSelectedRole } = props

  return (
    <FormControl className="rolelist" >
      <FormLabel id="demo-radio-buttons-group-label">{recursos.label}</FormLabel>
      <RadioGroup
        aria-labelledby="demo-radio-buttons-group-label"
        defaultValue="female"
        name="radio-buttons-group"
      >
        {

          recursos.data.length === 0 ? <Loading /> :
            recursos.data.map((r) => {
              return (
                <FormControlLabel
                  value={r.id}
                  onChange={(event) => {
                    let { checked } = event.target
                    setSelectedRole((prev) => {
                      if (checked) {
                        return [...prev, r.id]
                      } else {
                        return prev.filter((p) => p !== r.id)
                      }
                    })
                  }}
                  checked={selectedRole.includes(r.id)}
                  control={<Checkbox />}
                  label={r.nombre}
                />
              )
            })
        }
      </RadioGroup>
    </FormControl>
  );
}

function TipoUsuarios(props) {

  let { type, setType } = props

  const handleChange = (event) => setType(parseInt(event.target.value));

  return (
    <FormControl>
      <FormLabel id="demo-radio-buttons-group-label">Nivel de Acceso</FormLabel>
      <FormGroup
        className="seluser_type"
        row
        aria-labelledby="demo-row-radio-buttons-group-label"
        name="row-radio-buttons-group"
        value={type}
        onChange={handleChange}
      >
        <FormControlLabel
          value={ROLE.CANDIDATO}
          onChange={handleChange}
          checked={type === ROLE.CANDIDATO}
          control={<Checkbox />}
          label="Candidato"
        />
        <FormControlLabel
          value={ROLE.ADMIN}
          onChange={handleChange}
          checked={type === 1}
          control={<Checkbox />}
          label="Administrador"
        />
        <FormControlLabel
          value={ROLE.ASISTENTE}
          onChange={handleChange}
          checked={type === 2}
          control={<Checkbox />}
          label="Asistente"
        />
      </FormGroup>
    </FormControl>
  );
}


export function TypePwd(props) {
  // console.log(props)

  const auth = useSelector(state => state.token)
  const [recursos, setRecursos] = useState(null)
  const [selectedRole, setSelectedRole] = useState([])
  const [userType, setUserType] = useState(ROLE.CANDIDATO)
  const [user, setUser] = useState(null)

  const saveUser = () => {
    //TODO: trigger form submit
    console.log(user, selectedRole)
  }

  useEffect(() => {

    const getRecursos = () => {
      let rest = new Service('/recursos/allow')
      return rest.getQuery(auth.token);
    }
    const groupRecursos = (recursos) => {
      let groups = {};
      recursos.forEach((r) => {
        if (groups[r.grupo]) {
          groups[r.grupo].push(r)
        } else {
          groups[r.grupo] = [r]
        }
      })

      assignRecursos(groups)
    }

    const assignRecursos = (recursos_api) => {
      let templete = {
        1: { "label": 'Puestos', data: [] },
        2: { "label": 'Varios', data: [] },
        3: { "label": 'General', data: [] }
      }

      Object.keys(recursos_api)
        .forEach((k) => {
          templete[k].data = recursos_api[k];
        })

      setRecursos(templete)
    }

    getRecursos()
      .then(({ data }) => groupRecursos(data))
      .catch((err) => console.log('ERROR:', err))

  }, [auth.token])

  return (
    <div class="gapwdrole">

      <div className="typepwdlist">
        <TipoUsuarios type={userType} setType={setUserType} />
      </div>

      <Collapse orientation="vertical" in={parseInt(userType) === ROLE.ADMIN} >
        <div className="typepwdlist">
          <Title title="Informacion de la contraseña" step={"B"} />
          <PasswordInfoForm setUser={setUser} user={user} />
        </div>
      </Collapse>

      <Collapse orientation="vertical" in={parseInt(userType) === ROLE.ASISTENTE} >
        <div className="typepwdlist">
          <Title title="Informacion de la contraseña" step={"B"} />
          <PasswordInfoForm setUser={setUser} user={user} />
        </div>

        <div className="typepwdlist">
          <Title title="Selecciona los privilegios" step={"C"} />
          {
            recursos &&
            Object.keys(recursos).map((k) =>
              <PermisosList
                recursos={recursos[k]}
                selectedRole={selectedRole}
                setSelectedRole={setSelectedRole}
              />
            )}
        </div>
      </Collapse>

      <Box sx={{ mb: 2 }}>
        <div style={{ paddingTop: 15 }}>
          <Button
            onClick={parseInt(userType) === ROLE.CANDIDATO ? props.handleNext : saveUser}
            className="registerBtn"
            variant="contained"
            sx={{ mt: 1, mr: 1 }}
          >
            {parseInt(userType) === ROLE.CANDIDATO ? 'Siguiente' : 'Guardar'}
          </Button>
          <Button
            disabled={true}
            onClick={props.handleBack}
            sx={{ mt: 1, mr: 1 }}
          >
            Regresar
          </Button>
        </div>
      </Box>



    </div>
  )

}
